@@ -4,7 +4,7 @@
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_matching_dims.hpp>
+#include <stan/math/error_handling/matrix/check_matching_dims.hpp>
 #include <stan/agrad/fwd/matrix/typedefs.hpp>
 #include <stan/agrad/fwd/matrix/dot_product.hpp>
 #include <stan/agrad/fwd/fvar.hpp>
@@ -17,7 +17,8 @@ namespace stan {
     Eigen::Matrix<fvar<T>, 1, C1>
     columns_dot_product(const Eigen::Matrix<fvar<T>, R1, C1>& v1, 
                         const Eigen::Matrix<fvar<T>, R2, C2>& v2) {
-      stan::math::validate_matching_dims(v1,v2,"columns_dot_product");
+      stan::math::check_matching_dims("columns_dot_product(%1%)",v1,"v1",
+                                      v2,"v2",(double*)0);
       Eigen::Matrix<fvar<T>, 1, C1> ret(1,v1.cols());
       for (size_type j = 0; j < v1.cols(); ++j) {
         Eigen::Matrix<fvar<T>,R1,C1> ccol1 = v1.col(j);
@@ -32,9 +33,9 @@ namespace stan {
     Eigen::Matrix<fvar<T>, 1, C1>
     columns_dot_product(const Eigen::Matrix<fvar<T>, R1, C1>& v1, 
                         const Eigen::Matrix<double, R2, C2>& v2) {
-      stan::math::validate_matching_dims(v1,v2,"columns_dot_product");
-      Eigen::Matrix<fvar<T>, 1, C1> 
-        ret(1,v1.cols());
+      stan::math::check_matching_dims("columns_dot_product(%1%)",v1,"v1",
+                                      v2,"v2",(double*)0);
+      Eigen::Matrix<fvar<T>, 1, C1> ret(1,v1.cols());
       for (size_type j = 0; j < v1.cols(); ++j) {
         Eigen::Matrix<fvar<T>,R1,C1> ccol1 = v1.col(j);
         Eigen::Matrix<double,R2,C2> ccol = v2.col(j);
@@ -48,7 +49,8 @@ namespace stan {
     Eigen::Matrix<fvar<T>, 1, C1>
     columns_dot_product(const Eigen::Matrix<double, R1, C1>& v1, 
                         const Eigen::Matrix<fvar<T>, R2, C2>& v2) {
-      stan::math::validate_matching_dims(v1,v2,"columns_dot_product");
+      stan::math::check_matching_dims("columns_dot_product(%1%)",v1,"v1",
+                                      v2,"v2",(double*)0);
       Eigen::Matrix<fvar<T>, 1, C1> ret(1,v1.cols());
       for (size_type j = 0; j < v1.cols(); ++j) {
         Eigen::Matrix<double,R1,C1> ccol = v1.col(j);
