@@ -6,8 +6,8 @@
 #include <boost/type_traits.hpp>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_vector.hpp>
-#include <stan/math/matrix/validate_matching_sizes.hpp>
+#include <stan/math/error_handling/matrix/check_vector.hpp>
+#include <stan/math/error_handling/matrix/check_matching_sizes.hpp>
 #include <stan/math/functions/value_of.hpp>
 #include <stan/agrad/rev/var.hpp>
 #include <stan/agrad/rev/vari.hpp>
@@ -212,9 +212,10 @@ namespace stan {
                                 boost::is_same<T2,var>::value, var>::type
     dot_product(const Eigen::Matrix<T1, R1, C1>& v1, 
                 const Eigen::Matrix<T2, R2, C2>& v2) {
-      stan::math::validate_vector(v1,"dot_product");
-      stan::math::validate_vector(v2,"dot_product");
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_vector("dot_product(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("dot_product(%1%)",v2,"v2",(double*)0);
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       return var(new dot_product_vari<T1,T2>(v1,v2));
     }
     /**
@@ -247,7 +248,8 @@ namespace stan {
                                 boost::is_same<T2,var>::value, var>::type
     dot_product(const std::vector<T1>& v1,
                 const std::vector<T2>& v2) {
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       return var(new dot_product_vari<T1,T2>(&v1[0], &v2[0], v1.size()));
     }
 
@@ -258,7 +260,8 @@ namespace stan {
                                 Eigen::Matrix<var, 1, C1> >::type
     columns_dot_product(const Eigen::Matrix<T1, R1, C1>& v1, 
                         const Eigen::Matrix<T2, R2, C2>& v2) {
-      stan::math::validate_matching_sizes(v1,v2,"columns_dot_product");
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       Eigen::Matrix<var, 1, C1> ret(1,v1.cols());
       for (size_type j = 0; j < v1.cols(); ++j) {
         ret(j) = var(new dot_product_vari<T1,T2>(v1.col(j),v2.col(j)));
@@ -273,7 +276,8 @@ namespace stan {
                                 Eigen::Matrix<var, R1, 1> >::type
     rows_dot_product(const Eigen::Matrix<T1, R1, C1>& v1, 
                      const Eigen::Matrix<T2, R2, C2>& v2) {
-      stan::math::validate_matching_sizes(v1,v2,"rows_dot_product");
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       Eigen::Matrix<var, R1, 1> ret(v1.rows(),1);
       for (size_type j = 0; j < v1.rows(); ++j) {
         ret(j) = var(new dot_product_vari<T1,T2>(v1.row(j),v2.row(j)));
