@@ -8,6 +8,7 @@
 #include <stan/math/matrix/log_softmax.hpp>
 #include <stan/math/matrix/softmax.hpp>
 #include <stan/agrad/rev/var.hpp>
+#include <stan/math/error_handling/matrix/check_nonzero_size.hpp>
 
 namespace stan {
   namespace agrad {
@@ -60,7 +61,7 @@ namespace stan {
       using Eigen::Matrix;
       using Eigen::Dynamic;
 
-      stan::math::validate_nonzero_size(alpha,"vector argument to var log_softmax");
+      stan::math::check_nonzero_size("log_softmax(%1%)",alpha,"alpha",(double*)0);
 
       if (alpha.size() == 0) 
         throw std::domain_error("arg vector to log_softmax() must have size > 0");
