@@ -4,10 +4,10 @@
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
 #include <stan/agrad/rev/var.hpp>
 #include <stan/agrad/rev/matrix/typedefs.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace agrad {
@@ -245,9 +245,10 @@ namespace stan {
                      const Eigen::Matrix<var,R2,C2> &b) {
       Eigen::Matrix<var,R1,C2> res(b.rows(),b.cols());
       
-      stan::math::validate_square(A,"mdivide_left_spd");
-      stan::math::validate_multiplicable(A,b,"mdivide_left_spd");
-      
+      stan::math::check_square("mdivide_left_spd(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_spd(%1%)",A,"A",
+                                      b,"b",(double*)0);      
+
       // NOTE: this is not a memory leak, this vari is used in the 
       // expression graph to evaluate the adjoint, but is not needed
       // for the returned matrix.  Memory will be cleaned up with the arena allocator.
@@ -268,8 +269,9 @@ namespace stan {
                      const Eigen::Matrix<double,R2,C2> &b) {
       Eigen::Matrix<var,R1,C2> res(b.rows(),b.cols());
       
-      stan::math::validate_square(A,"mdivide_left_spd");
-      stan::math::validate_multiplicable(A,b,"mdivide_left_spd");
+      stan::math::check_square("mdivide_left_spd(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_spd(%1%)",A,"A",
+                                      b,"b",(double*)0);    
       
       // NOTE: this is not a memory leak, this vari is used in the 
       // expression graph to evaluate the adjoint, but is not needed
@@ -291,8 +293,9 @@ namespace stan {
                      const Eigen::Matrix<var,R2,C2> &b) {
       Eigen::Matrix<var,R1,C2> res(b.rows(),b.cols());
       
-      stan::math::validate_square(A,"mdivide_left_spd");
-      stan::math::validate_multiplicable(A,b,"mdivide_left_spd");
+      stan::math::check_square("mdivide_left_spd(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_spd(%1%)",A,"A",
+                                      b,"b",(double*)0);    
       
       // NOTE: this is not a memory leak, this vari is used in the 
       // expression graph to evaluate the adjoint, but is not needed
