@@ -32,20 +32,18 @@ namespace stan {
      * @param stan_gm_in
      * @param cpp_out
      * @param model_name
-     * @param include_main
      * @param in_file_name
      */
     bool compile(std::ostream* msgs, // for warnings
                  std::istream& stan_gm_in,
                  std::ostream& cpp_out,
                  const std::string& model_name,
-                 bool include_main = true,
                  const std::string& in_file_name = "input") {
       program prog;
       bool parsed_ok = parse(msgs,stan_gm_in,in_file_name,model_name,prog);
       if (!parsed_ok) 
         return false; // syntax error in program
-      generate_cpp(prog,model_name,cpp_out,include_main);
+      generate_cpp(prog,model_name,cpp_out);
       return true;
     }
     
