@@ -39,7 +39,8 @@ namespace stan {
         std::stringstream msg;
         msg << "in function check_unit_vector(%1%), ";
         msg << name << " is not a valid unit vector.";
-        msg << " The sum of the squares of the elements should be 1, but is " << ssq;
+        msg << " The sum of the squares of the elements should be 1, but is " 
+            << ssq;
         std::string tmp(msg.str());
         return dom_err(function,ssq,name,
                        tmp.c_str(),"",
@@ -48,6 +49,16 @@ namespace stan {
       return true;
     }
 
+
+    template <typename T>
+    inline bool check_unit_vector(const char* function,
+                                  const Eigen::Matrix<T,Eigen::Dynamic,1>& theta,
+                                  const char* name,
+                                  T* result = 0) {
+      return check_unit_vector<T,T>(function,theta,name,result);
+    }
+
+
   }
 }
 #endif
