@@ -21,7 +21,8 @@ namespace stan {
     template <typename T>
     inline typename boost::math::tools::promote_args<T>::type
     Phi_approx(T x) {
-      return inv_logit(0.07056 * std::pow(x,3.0) + 1.5976 * x);
+      using std::pow;
+      return inv_logit(0.07056 * pow(x,3.0) + 1.5976 * x);
     }
 
   }
