@@ -14,12 +14,15 @@ namespace stan {
                   const Eigen::Matrix<T2,R2,C2>& m2) {
       if (m2.cols() != 1 && m2.rows() != 1)
         throw std::domain_error("m2 must be a vector");
-      if (m2.size() != m1.cols())
+      int m1_cols = m1.cols();
+      if (m2.size() != m1_cols)
         throw std::domain_error("m2 must have same length as m1 has columns");
+      int m1_rows = m1.rows();
       Eigen::Matrix<typename boost::math::tools::promote_args<T1,T2>::type, R1, C1>
-        result(m1.rows(),m1.cols());
-      for (int j = 0; j < m1.cols(); ++j)
-        for (int i = 0; i < m1.rows(); ++i)
+        result(m1_rows, m1_cols);
+      
+      for (int j = 0; j < m1_cols; ++j)
+        for (int i = 0; i < m1_rows; ++i)
           result(i,j) = m2(j) * m1(i,j);
       return result;
     }
