@@ -4,7 +4,7 @@
 
 #include <cmath>
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace math {
@@ -19,7 +19,7 @@ namespace stan {
     template <typename T,int R, int C>
     inline T log_determinant_spd(const Eigen::Matrix<T,R,C>& m) {
       using std::log;
-      stan::math::validate_square(m,"log_determinant_spd");
+      stan::math::check_square("log_determinant_spd(%1%)",m,"m",(double*)0);
 //      Eigen::TriangularView< Eigen::Matrix<T,R,C>, Eigen::Lower > L(m.llt().matrixL());
 //      T ret(0.0);
 //      for (size_t i = 0; i < L.rows(); i++)
