@@ -5,8 +5,8 @@
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/mdivide_left_spd.hpp>
 #include <stan/math/matrix/transpose.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace math {
@@ -25,8 +25,9 @@ namespace stan {
     Eigen::Matrix<typename boost::math::tools::promote_args<T1,T2>::type,R1,C2>
     mdivide_right_spd(const Eigen::Matrix<T1,R1,C1> &b,
                       const Eigen::Matrix<T2,R2,C2> &A) {
-      stan::math::validate_square(A,"mdivide_right_spd");
-      stan::math::validate_multiplicable(b,A,"mdivide_right_spd");
+      stan::math::check_square("mdivide_right_spd(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_right_spd(%1%)",b,"b",
+                                      A,"A",(double*)0);
       // FIXME: This is nice and general but likely slow.
       return transpose(mdivide_left_spd(A,transpose(b)));
     }
