@@ -2,8 +2,8 @@
 #define __STAN__MATH__MATRIX__SQUARED_DISTANCE_HPP__
 
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_vector.hpp>
-#include <stan/math/matrix/validate_matching_sizes.hpp>
+#include <stan/math/error_handling/matrix/check_vector.hpp>
+#include <stan/math/error_handling/matrix/check_matching_sizes.hpp>
 
 namespace stan {
   namespace math {
@@ -20,9 +20,10 @@ namespace stan {
     template<int R1,int C1,int R2, int C2>
     inline double squared_distance(const Eigen::Matrix<double, R1, C1>& v1, 
                                    const Eigen::Matrix<double, R2, C2>& v2) {
-      validate_vector(v1,"squared_distance");
-      validate_vector(v2,"squared_distance");
-      validate_matching_sizes(v1,v2,"squared_distance");
+      stan::math::check_vector("squared_distance(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("squared_distance(%1%)",v2,"v2",(double*)0);
+      stan::math::check_matching_sizes("squared_distance(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       if (v1.rows() != v2.rows())
         return (v1.transpose()-v2).squaredNorm();
       else
