@@ -2,8 +2,8 @@
 #define __STAN__MATH__MATRIX__SUB_ROW_HPP__
 
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_row_index.hpp>
-#include <stan/math/matrix/validate_column_index.hpp>
+#include <stan/math/error_handling/matrix/check_row_index.hpp>
+#include <stan/math/error_handling/matrix/check_column_index.hpp>
 
 namespace stan {
 
@@ -22,9 +22,11 @@ namespace stan {
     Eigen::Matrix<T,1,Eigen::Dynamic>
     sub_row(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& m,
                size_t i, size_t j, size_t ncols) {
-      validate_row_index(m,i,"sub_row");
-      validate_column_index(m,j,"sub_row");
-      if (ncols > 0) validate_column_index(m,j+ncols-1,"sub_row");
+      stan::math::check_row_index("sub_row(%1%)",i,m,"i",(double*)0);
+      stan::math::check_column_index("sub_row(%1%)",j,m,"j",(double*)0);
+      if (ncols > 0)
+        stan::math::check_column_index("sub_col(%1%)",j+ncols-1,m,"j+ncols-1",
+                                       (double*)0);
       return m.block(i - 1,j - 1,1,ncols);
     }
 
