@@ -3,7 +3,7 @@
 
 #include <vector>
 
-#include <stan/math/validate_non_negative_rep.hpp>
+#include <stan/math/error_handling/check_nonnegative.hpp>
 
 namespace stan {
 
@@ -12,7 +12,7 @@ namespace stan {
     template <typename T>
     inline std::vector<T>
     rep_array(const T& x, int n) {
-      validate_non_negative_rep(n,"rep_array 1D");
+      check_nonnegative("rep_array(%1%)", n,"n", (double*)0);
       return std::vector<T>(n,x);
     }
 
@@ -20,8 +20,8 @@ namespace stan {
     inline std::vector<std::vector<T> >
     rep_array(const T& x, int m, int n) {
       using std::vector;
-      validate_non_negative_rep(m,"rep_array 2D rows");
-      validate_non_negative_rep(n,"rep_array 2D cols");
+      check_nonnegative("rep_array(%1%)", m,"rows", (double*)0);
+      check_nonnegative("rep_array(%1%)", n,"cols", (double*)0);
       return vector<vector<T> >(m, vector<T>(n, x));
     }
 
@@ -29,9 +29,9 @@ namespace stan {
     inline std::vector<std::vector<std::vector<T> > >
     rep_array(const T& x, int k, int m, int n) {
       using std::vector;
-      validate_non_negative_rep(k,"rep_array 2D shelfs");
-      validate_non_negative_rep(m,"rep_array 2D rows");
-      validate_non_negative_rep(n,"rep_array 2D cols");
+      check_nonnegative("rep_array(%1%)", k,"shelfs", (double*)0);
+      check_nonnegative("rep_array(%1%)", m,"rows", (double*)0);
+      check_nonnegative("rep_array(%1%)", n,"cols", (double*)0);
       return vector<vector<vector<T> > >(k,
                                          vector<vector<T> >(m,
                                                             vector<T>(n, x)));
