@@ -5,9 +5,13 @@
 #include <boost/random/variate_generator.hpp>
 
 #include <stan/agrad/partials_vari.hpp>
-#include <stan/math/error_handling.hpp>
+#include <stan/math/error_handling/check_not_nan.hpp>
+#include <stan/math/error_handling/check_positive.hpp>
+#include <stan/math/error_handling/check_finite.hpp>
+#include <stan/math/error_handling/check_consistent_sizes.hpp>
 #include <stan/math/constants.hpp>
 #include <stan/math/functions/value_of.hpp>
+#include <stan/math/functions/log1p.hpp>
 #include <stan/meta/traits.hpp>
 #include <stan/prob/constants.hpp>
 #include <stan/prob/traits.hpp>
@@ -40,22 +44,15 @@ namespace stan {
       double logp(0.0);
         
       // validate args (here done over var, which should be OK)      
-      if (!check_finite(function, y, "Random variable", &logp))
-        return logp;
-      if (!check_finite(function, mu, "Location parameter",
-                        &logp))
-        return logp;
-      if (!check_finite(function, sigma, "Scale parameter", &logp))
-        return logp;
-      if (!check_positive(function, sigma, "Scale parameter",
-                          &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,mu,sigma,
-                                   "Random variable","Location parameter",
-                                   "Scale parameter",
-                                   &logp)))
-        return logp;
+      check_finite(function, y, "Random variable", &logp);
+      check_finite(function, mu, "Location parameter", &logp);
+      check_finite(function, sigma, "Scale parameter", &logp);
+      check_positive(function, sigma, "Scale parameter", &logp);
+      check_consistent_sizes(function,
+                             y,mu,sigma,
+                             "Random variable","Location parameter",
+                             "Scale parameter",
+                             &logp);
 
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_y,T_loc,T_scale>::value)
@@ -163,18 +160,13 @@ namespace stan {
           
       double P(1.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, mu, "Location parameter", &P))
-        return P;
-      if (!check_finite(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale parameter", &P)))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_finite(function, mu, "Location parameter", &P);
+      check_finite(function, sigma, "Scale parameter", &P);
+      check_positive(function, sigma, "Scale parameter", &P);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -262,18 +254,13 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, mu, "Location parameter", &P))
-        return P;
-      if (!check_finite(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale parameter", &P)))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_finite(function, mu, "Location parameter", &P);
+      check_finite(function, sigma, "Scale parameter", &P);
+      check_positive(function, sigma, "Scale parameter", &P);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -346,18 +333,13 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, mu, "Location parameter", &P))
-        return P;
-      if (!check_finite(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale parameter", &P)))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_finite(function, mu, "Location parameter", &P);
+      check_finite(function, sigma, "Scale parameter", &P);
+      check_positive(function, sigma, "Scale parameter", &P);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -423,12 +405,9 @@ namespace stan {
       using stan::math::check_positive;
       using stan::math::check_finite;
 
-      if (!check_finite(function, mu, "Location parameter"))
-        return 0;
-      if (!check_finite(function, sigma, "Scale parameter"))
-        return 0;
-      if (!check_positive(function, sigma, "Scale parameter"))
-        return 0;
+      check_finite(function, mu, "Location parameter", (double*)0);
+      check_finite(function, sigma, "Scale parameter", (double*)0);
+      check_positive(function, sigma, "Scale parameter", (double*)0);
 
       variate_generator<RNG&, exponential_distribution<> >
         exp_rng(rng, exponential_distribution<>(1));
