@@ -65,30 +65,18 @@ namespace stan {
       double logp(0.0);
 
       // validate args (here done over var, which should be OK)
-      if (!check_not_nan(function, y, "Random variable", &logp))
-        return logp;
-      if(!check_finite(function, nu, "Degrees of freedom parameter", 
-                       &logp))
-        return logp;
-      if(!check_positive(function, nu, "Degrees of freedom parameter", 
-                         &logp))
-        return logp;
-      if (!check_finite(function, mu, "Location parameter", 
-                        &logp))
-        return logp;
-      if (!check_finite(function, sigma, "Scale parameter", 
-                        &logp))
-        return logp;
-      if (!check_positive(function, sigma, "Scale parameter", 
-                          &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,nu,mu,sigma,
-                                   "Random variable",
-                                   "Degrees of freedom parameter",
-                                   "Location parameter","Scale parameter",
-                                   &logp)))
-        return logp;
+      check_not_nan(function, y, "Random variable", &logp);
+      check_finite(function, nu, "Degrees of freedom parameter", &logp);
+      check_positive(function, nu, "Degrees of freedom parameter", &logp);
+      check_finite(function, mu, "Location parameter", &logp);
+      check_finite(function, sigma, "Scale parameter", &logp);
+      check_positive(function, sigma, "Scale parameter", &logp);
+      check_consistent_sizes(function,
+                             y,nu,mu,sigma,
+                             "Random variable",
+                             "Degrees of freedom parameter",
+                             "Location parameter","Scale parameter",
+                             &logp);
 
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_y,T_dof,T_loc,T_scale>::value)
@@ -247,18 +235,12 @@ namespace stan {
           
       double P(1.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_positive(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_finite(function, mu, "Location parameter", &P))
-        return P;
-      if (!check_finite(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, sigma, "Scale parameter", &P))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_finite(function, nu, "Degrees of freedom parameter", &P);
+      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_finite(function, mu, "Location parameter", &P);
+      check_finite(function, sigma, "Scale parameter", &P);
+      check_positive(function, sigma, "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -429,18 +411,12 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_positive(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_finite(function, mu, "Location parameter", &P))
-        return P;
-      if (!check_finite(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, sigma, "Scale parameter", &P))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_finite(function, nu, "Degrees of freedom parameter", &P);
+      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_finite(function, mu, "Location parameter", &P);
+      check_finite(function, sigma, "Scale parameter", &P);
+      check_positive(function, sigma, "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -599,18 +575,12 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_positive(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_finite(function, mu, "Location parameter", &P))
-        return P;
-      if (!check_finite(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, sigma, "Scale parameter", &P))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_finite(function, nu, "Degrees of freedom parameter", &P);
+      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_finite(function, mu, "Location parameter", &P);
+      check_finite(function, sigma, "Scale parameter", &P);
+      check_positive(function, sigma, "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -763,16 +733,11 @@ namespace stan {
       using stan::math::check_positive;
       using stan::math::check_finite;
 
-      if(!check_finite(function, nu, "Degrees of freedom parameter"))
-        return 0;
-      if(!check_positive(function, nu, "Degrees of freedom parameter")) 
-        return 0;
-      if (!check_finite(function, mu, "Location parameter")) 
-        return 0;
-      if (!check_finite(function, sigma, "Scale parameter")) 
-        return 0;
-      if (!check_positive(function, sigma, "Scale parameter"))
-        return 0;
+      check_finite(function, nu, "Degrees of freedom parameter", (double*)0);
+      check_positive(function, nu, "Degrees of freedom parameter", (double*)0);
+      check_finite(function, mu, "Location parameter", (double*)0);
+      check_finite(function, sigma, "Scale parameter", (double*)0); 
+      check_positive(function, sigma, "Scale parameter", (double*)0);
 
       variate_generator<RNG&, student_t_distribution<> >
         rng_unit_student_t(rng, student_t_distribution<>(nu));
