@@ -18,7 +18,6 @@
 #include <stan/model/util.hpp>
 
 #include <stan/optimization/newton.hpp>
-#include <stan/optimization/nesterov_gradient.hpp>
 #include <stan/optimization/bfgs.hpp>
 
 #include <stan/mcmc/hmc/static/adapt_unit_e_static_hmc.hpp>
@@ -29,13 +28,17 @@
 #include <stan/mcmc/hmc/nuts/adapt_dense_e_nuts.hpp>
 #include <stan/mcmc/fixed_param_sampler.hpp>
 
+
 #include <stan/common/do_print.hpp>
+#include <stan/common/do_bfgs_optimize.hpp>
 #include <stan/common/print_progress.hpp>
 
+
 #include "py_var_context.hpp"
 void Py_CheckUserInterrupt(void);
 
 // REF: stan/common/command.hpp
+
 #include <stan/io/mcmc_writer.hpp>
 #include <stan/common/recorder/messages.hpp>
 #include <stan/common/warmup.hpp>
@@ -53,7 +56,7 @@ void Py_CheckUserInterrupt(void) {
 namespace pystan {
 
   enum sampling_algo_t { NUTS = 1, HMC = 2, Metropolis = 3, Fixed_param = 4};
-  enum optim_algo_t { Newton = 1, Nesterov = 2, BFGS = 3};
+  enum optim_algo_t { Newton = 1, BFGS = 3, LBFGS = 4};
   enum sampling_metric_t { UNIT_E = 1, DIAG_E = 2, DENSE_E = 3};
   enum stan_args_method_t { SAMPLING = 1, OPTIM = 2, TEST_GRADIENT = 3};
 
@@ -106,13 +109,15 @@ namespace pystan {
       struct {
         int iter; // default to 2000
         int refresh; // default to 100
-        optim_algo_t algorithm; // Newton, Nesterov, BFGS
+        optim_algo_t algorithm; // Newton, (L)BFGS
         bool save_iterations; // default to false
-        double stepsize; // default to 1, for Nesterov
-        double init_alpha; // default to 0.0001, for BFGS
-        double tol_obj; // default to 1e-8, for BFGS
-        double tol_grad; // default to 1e-8, for BFGS
-        double tol_param; // default to 1e-8, for BFGS
+        double init_alpha; // default to 0.0001, for (L)BFGS
+        double tol_obj; // default to 1e-12, for (L)BFGS
+        double tol_grad; // default to 1e-8, for (L)BFGS
+        double tol_param; // default to 1e-8, for (L)BFGS
+        double tol_rel_obj; // default to 1e4, for (L)BFGS
+        double tol_rel_grad; // default to 1e7, for (L)BFGS
+        int history_size; // default to 5, for LBFGS only
       } optim;
       struct {
         double epsilon; // default to 1e-6, for test_grad
@@ -227,9 +232,6 @@ namespace pystan {
     inline bool get_ctrl_optim_save_iterations() const {
       return ctrl.optim.save_iterations;
     }
-    inline double get_ctrl_optim_stepsize() const {
-      return ctrl.optim.stepsize;
-    }
     inline double get_ctrl_optim_init_alpha() const {
       return ctrl.optim.init_alpha;
     }
@@ -242,10 +244,19 @@ namespace pystan {
     inline double get_ctrl_optim_tol_param() const {
       return ctrl.optim.tol_param;
     }
-    double get_ctrl_test_grad_epsilon() const {
+    inline double get_ctrl_optim_tol_rel_obj() const {
+      return ctrl.optim.tol_rel_obj;
+    }
+    inline double get_ctrl_optim_tol_rel_grad() const {
+      return ctrl.optim.tol_rel_grad;
+    }
+    inline int get_ctrl_optim_history_size() const {
+      return ctrl.optim.history_size;
+    }
+    inline double get_ctrl_test_grad_epsilon() const {
       return ctrl.test_grad.epsilon;
     }
-    double get_ctrl_test_grad_error() const {
+    inline double get_ctrl_test_grad_error() const {
       return ctrl.test_grad.error;
     }
     inline unsigned int get_chain_id() const {
@@ -973,7 +984,76 @@ namespace pystan {
       }
 
       if (OPTIM == args.get_method()) { // point estimation
-        if (BFGS == args.get_ctrl_optim_algorithm()) {
+        if (LBFGS == args.get_ctrl_optim_algorithm()) {
+          std::cout << "STAN OPTIMIZATION COMMAND (LBFGS)" << std::endl;
+          std::cout << "init = " << init_val << std::endl;
+          if (num_init_tries > 0)
+            std::cout << "init tries = " << num_init_tries << std::endl;
+          if (args.get_sample_file_flag())
+            std::cout << "output = " << args.get_sample_file() << std::endl;
+          std::cout << "save_iterations = " << args.get_ctrl_optim_save_iterations() << std::endl;
+          std::cout << "init_alpha = " << args.get_ctrl_optim_init_alpha() << std::endl;
+          std::cout << "tol_obj = " << args.get_ctrl_optim_tol_obj() << std::endl;
+          std::cout << "tol_grad = " << args.get_ctrl_optim_tol_grad() << std::endl;
+          std::cout << "tol_param = " << args.get_ctrl_optim_tol_param() << std::endl;
+          std::cout << "tol_rel_obj = " << args.get_ctrl_optim_tol_rel_obj() << std::endl;
+          std::cout << "tol_rel_grad = " << args.get_ctrl_optim_tol_rel_grad() << std::endl;
+          std::cout << "history_size = " << args.get_ctrl_optim_history_size() << std::endl;
+          std::cout << "seed = " << args.get_random_seed() << std::endl;
+
+          if (args.get_sample_file_flag()) {
+            write_comment(sample_stream,"Point Estimate Generated by Stan (LBFGS)");
+            write_comment(sample_stream);
+            write_comment_property(sample_stream,"stan_version_major",stan::MAJOR_VERSION);
+            write_comment_property(sample_stream,"stan_version_minor",stan::MINOR_VERSION);
+            write_comment_property(sample_stream,"stan_version_patch",stan::PATCH_VERSION);
+            write_comment_property(sample_stream,"init",init_val);
+            write_comment_property(sample_stream,"save_iterations",args.get_ctrl_optim_save_iterations());
+            write_comment_property(sample_stream,"init_alpha",args.get_ctrl_optim_init_alpha());
+            write_comment_property(sample_stream,"tol_obj",args.get_ctrl_optim_tol_obj());
+            write_comment_property(sample_stream,"tol_grad",args.get_ctrl_optim_tol_grad());
+            write_comment_property(sample_stream,"tol_param",args.get_ctrl_optim_tol_param());
+            write_comment_property(sample_stream,"tol_rel_obj", args.get_ctrl_optim_tol_rel_obj());
+            write_comment_property(sample_stream,"tol_rel_grad", args.get_ctrl_optim_tol_rel_grad());
+            write_comment_property(sample_stream,"history_size", args.get_ctrl_optim_history_size());
+            write_comment_property(sample_stream,"seed",args.get_random_seed());
+            write_comment(sample_stream);
+
+            sample_stream << "lp__,"; // log probability first
+            model.write_csv_header(sample_stream);
+          }
+
+          double lp(0);
+          bool save_iterations = args.get_ctrl_optim_save_iterations();
+          int refresh = args.get_ctrl_sampling_refresh();
+
+          typedef stan::optimization::BFGSLineSearch<Model,stan::optimization::LBFGSUpdate<> > Optimizer;
+          Optimizer lbfgs(model, cont_vector, disc_vector, &std::cout);
+
+          lbfgs.get_qnupdate().set_history_size(args.get_ctrl_optim_history_size());
+
+          lbfgs._ls_opts.alpha0       = args.get_ctrl_optim_init_alpha();
+          lbfgs._conv_opts.tolAbsF    = args.get_ctrl_optim_tol_obj();
+          lbfgs._conv_opts.tolRelF    = args.get_ctrl_optim_tol_rel_obj();
+          lbfgs._conv_opts.tolAbsGrad = args.get_ctrl_optim_tol_grad();
+          lbfgs._conv_opts.tolRelGrad = args.get_ctrl_optim_tol_rel_grad();
+          lbfgs._conv_opts.tolAbsX    = args.get_ctrl_optim_tol_param();
+          lbfgs._conv_opts.maxIts     = args.get_iter();
+
+          int return_code = stan::common::do_bfgs_optimize(model, lbfgs, base_rng,
+                                                           lp, cont_vector, disc_vector,
+                                                           &sample_stream, &std::cout,
+                                                           save_iterations, refresh);
+
+          if (args.get_sample_file_flag()) {
+            stan::common::write_iteration(sample_stream, model, base_rng,
+                                          lp, cont_vector, disc_vector);
+            sample_stream.close();
+          }
+          model.write_array(base_rng,cont_vector,disc_vector, params_inr_etc);
+          holder.par = params_inr_etc;
+          holder.value = lp;
+        } else if (BFGS == args.get_ctrl_optim_algorithm()) {
           std::cout << "STAN OPTIMIZATION COMMAND (BFGS)" << std::endl;
           std::cout << "init = " << init_val << std::endl;
           if (num_init_tries > 0)
@@ -985,6 +1065,8 @@ namespace pystan {
           std::cout << "tol_obj = " << args.get_ctrl_optim_tol_obj() << std::endl;
           std::cout << "tol_grad = " << args.get_ctrl_optim_tol_grad() << std::endl;
           std::cout << "tol_param = " << args.get_ctrl_optim_tol_param() << std::endl;
+          std::cout << "tol_rel_obj = " << args.get_ctrl_optim_tol_rel_obj() << std::endl;
+          std::cout << "tol_rel_grad = " << args.get_ctrl_optim_tol_rel_grad() << std::endl;
           std::cout << "seed = " << args.get_random_seed() << std::endl;
 
           if (args.get_sample_file_flag()) {
@@ -999,76 +1081,42 @@ namespace pystan {
             write_comment_property(sample_stream,"tol_obj",args.get_ctrl_optim_tol_obj());
             write_comment_property(sample_stream,"tol_grad",args.get_ctrl_optim_tol_grad());
             write_comment_property(sample_stream,"tol_param",args.get_ctrl_optim_tol_param());
+            write_comment_property(sample_stream,"tol_rel_obj", args.get_ctrl_optim_tol_rel_obj());
+            write_comment_property(sample_stream,"tol_rel_grad", args.get_ctrl_optim_tol_rel_grad());
             write_comment_property(sample_stream,"seed",args.get_random_seed());
             write_comment(sample_stream);
 
             sample_stream << "lp__,"; // log probability first
             model.write_csv_header(sample_stream);
           }
+          double lp(0);
+          bool save_iterations = args.get_ctrl_optim_save_iterations();
+          int refresh = args.get_ctrl_sampling_refresh();
 
-          stan::optimization::BFGSLineSearch<Model> bfgs(model, cont_vector, disc_vector,
-                                                         &std::cout);
-          bfgs._opts.alpha0 = args.get_ctrl_optim_init_alpha();
-          bfgs._opts.tolF = args.get_ctrl_optim_tol_obj();
-          bfgs._opts.tolGrad = args.get_ctrl_optim_tol_grad();
-          bfgs._opts.tolX = args.get_ctrl_optim_tol_param();
-          bfgs._opts.maxIts = args.get_iter();
+          typedef stan::optimization::BFGSLineSearch<Model,stan::optimization::BFGSUpdate_HInv<> > Optimizer;
+          Optimizer bfgs(model, cont_vector, disc_vector, &std::cout);
 
-          double lp = bfgs.logp();
+          bfgs._ls_opts.alpha0       = args.get_ctrl_optim_init_alpha();
+          bfgs._conv_opts.tolAbsF    = args.get_ctrl_optim_tol_obj();
+          bfgs._conv_opts.tolRelF    = args.get_ctrl_optim_tol_rel_obj();
+          bfgs._conv_opts.tolAbsGrad = args.get_ctrl_optim_tol_grad();
+          bfgs._conv_opts.tolRelGrad = args.get_ctrl_optim_tol_rel_grad();
+          bfgs._conv_opts.tolAbsX    = args.get_ctrl_optim_tol_param();
+          bfgs._conv_opts.maxIts     = args.get_iter();
 
-          std::cout << "initial log joint probability = " << lp << std::endl;
-          int ret = 0;
-          while (0 == ret) {
-            int i = bfgs.iter_num();
-            if (stan::common::do_print(i, i==0, 50 * args.get_ctrl_optim_refresh())) {
-              std::cout << "    Iter ";
-              std::cout << "     log prob ";
-              std::cout << "       ||dx|| ";
-              std::cout << "     ||grad|| ";
-              std::cout << "      alpha ";
-              std::cout << " # evals ";
-              std::cout << " Notes " << std::endl;
-            }
-            ret = bfgs.step();
-            lp = bfgs.logp();
-            bfgs.params_r(cont_vector);
+          int return_code = stan::common::do_bfgs_optimize(model, bfgs, base_rng,
+                                                           lp, cont_vector, disc_vector,
+                                                           &sample_stream, &std::cout,
+                                                           save_iterations, refresh);
 
-            if (stan::common::do_print(i, i==0, args.get_ctrl_optim_refresh())
-                || ret != 0 || !bfgs.note().empty()) {
-              std::cout << " " << std::setw(7) << i << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) << lp << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) << bfgs.prev_step_size() << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) << bfgs.curr_g().norm() << " ";
-              std::cout << " " << std::setw(10) << std::setprecision(4) << bfgs.alpha() << " ";
-              std::cout << " " << std::setw(7) << bfgs.grad_evals() << " ";
-              std::cout << " " << bfgs.note() << " ";
-              std::cout << std::endl;
-              std::cout.flush();
-            }
-
-            if (args.get_ctrl_optim_save_iterations()) {
-              sample_stream << lp << ',';
-              model.write_csv(base_rng,cont_vector,disc_vector,sample_stream);
-              sample_stream.flush();
-            }
+          if (args.get_sample_file_flag()) {
+            stan::common::write_iteration(sample_stream, model, base_rng,
+                                          lp, cont_vector, disc_vector);
+            sample_stream.close();
           }
-          if (args.get_ctrl_optim_refresh() > 0) {
-            if (ret >= 0) {
-                std::cout << "Optimization terminated normally: ";
-            } else {
-              std::cout << "Optimization terminated with error: ";
-            }
-            std::cout << bfgs.get_code_string(ret) << std::endl;
-          }
-
           model.write_array(base_rng,cont_vector,disc_vector,params_inr_etc);
           holder.par = params_inr_etc;
           holder.value = lp;
-          if (args.get_sample_file_flag()) {
-            sample_stream << lp << ',';
-            print_vector(params_inr_etc, sample_stream);
-            sample_stream.close();
-          }
         } else if (Newton == args.get_ctrl_optim_algorithm()) {
           std::cout << "STAN OPTIMIZATION COMMAND (Newton)" << std::endl;
           if (args.get_sample_file_flag()) {
@@ -1094,12 +1142,14 @@ namespace pystan {
             Py_CheckUserInterrupt();
             lastlp = lp;
             lp = stan::optimization::newton_step(model, cont_vector, disc_vector);
-            std::cout << "Iteration ";
-            std::cout << std::setw(2) << (m + 1) << ". ";
-            std::cout << "Log joint probability = " << std::setw(10) << lp;
-            std::cout << ". Improved by " << (lp - lastlp) << ".";
-            std::cout << std::endl;
-            std::cout.flush();
+            if (args.get_ctrl_optim_refresh() > 0) {
+                std::cout << "Iteration ";
+                std::cout << std::setw(2) << (m + 1) << ". ";
+                std::cout << "Log joint probability = " << std::setw(10) << lp;
+                std::cout << ". Improved by " << (lp - lastlp) << ".";
+                std::cout << std::endl;
+                std::cout.flush();
+            }
             m++;
             if (args.get_sample_file_flag()) {
               sample_stream << lp << ',';
@@ -1110,60 +1160,6 @@ namespace pystan {
           holder.par = params_inr_etc;
           holder.value = lp;
 
-          if (args.get_sample_file_flag()) {
-            sample_stream << lp << ',';
-            print_vector(params_inr_etc, sample_stream);
-            sample_stream.close();
-          }
-        } else if (Nesterov == args.get_ctrl_optim_algorithm()) {
-          std::cout << "STAN OPTIMIZATION COMMAND (Nesterov)" << std::endl;
-          std::cout << "stepsize = " << args.get_ctrl_optim_stepsize() << std::endl;
-          if (args.get_sample_file_flag()) {
-            write_comment(sample_stream,"Point Estimate Generated by Stan (Nesterov)");
-            write_comment(sample_stream);
-            write_comment_property(sample_stream,"stan_version_major",stan::MAJOR_VERSION);
-            write_comment_property(sample_stream,"stan_version_minor",stan::MINOR_VERSION);
-            write_comment_property(sample_stream,"stan_version_patch",stan::PATCH_VERSION);
-            write_comment_property(sample_stream,"init",init_val);
-            write_comment_property(sample_stream,"seed",args.get_random_seed());
-            write_comment_property(sample_stream,"stepsize",args.get_ctrl_optim_stepsize());
-            write_comment(sample_stream);
-
-            sample_stream << "lp__,"; // log probability first
-            model.write_csv_header(sample_stream);
-          }
-
-          stan::optimization::NesterovGradient<Model> ng(model, cont_vector, disc_vector,
-                                                         args.get_ctrl_optim_stepsize(),
-                                                         &std::cout);
-          double lp = ng.logp();
-          double lastlp = lp - 1;
-          std::cout << "initial log joint probability = " << lp << std::endl;
-          int m = 0;
-          for (int i = 0; i < args.get_iter(); i++) {
-            Py_CheckUserInterrupt();
-            lastlp = lp;
-            lp = ng.step();
-            ng.params_r(cont_vector);
-            if (stan::common::do_print(i, i==0, args.get_ctrl_optim_refresh())) {
-              std::cout << "Iteration ";
-              std::cout << std::setw(2) << (m + 1) << ". ";
-              std::cout << "Log joint probability = " << std::setw(10) << lp;
-              std::cout << ". Improved by " << (lp - lastlp) << ".";
-              std::cout << std::endl;
-              std::cout.flush();
-            }
-            m++;
-            if (args.get_sample_file_flag()) {
-              sample_stream << lp << ',';
-              model.write_csv(base_rng,cont_vector,disc_vector,sample_stream);
-            }
-          }
-
-          sample_stream << lp << ',';
-          model.write_array(base_rng,cont_vector,disc_vector,params_inr_etc);
-          holder.par = params_inr_etc;
-          holder.value = lp;
           if (args.get_sample_file_flag()) {
             sample_stream << lp << ',';
             print_vector(params_inr_etc, sample_stream);
